==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/waf/kotlin/inputs/XssMatchSetXssMatchTupleFieldToMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.waf.kotlin.inputs

import com.pulumi.aws.waf.inputs.XssMatchSetXssMatchTupleFieldToMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property data When `type` is `HEADER`, enter the name of the header that you want to search, e.g., `User-Agent` or `Referer`.
 * If `type` is any other value, omit this field.
 * @property type The part of the web request that you want AWS WAF to search for a specified string.
 * e.g., `HEADER`, `METHOD` or `BODY`.
 * See [docs](http://docs.aws.amazon.com/waf/latest/APIReference/API_FieldToMatch.html)
 * for all supported values.
 */
public data class XssMatchSetXssMatchTupleFieldToMatchArgs(
    public val `data`: Output<String>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.waf.inputs.XssMatchSetXssMatchTupleFieldToMatchArgs> {
    override fun toJava(): com.pulumi.aws.waf.inputs.XssMatchSetXssMatchTupleFieldToMatchArgs =
        com.pulumi.aws.waf.inputs.XssMatchSetXssMatchTupleFieldToMatchArgs.builder()
            .`data`(`data`?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [XssMatchSetXssMatchTupleFieldToMatchArgs].
 */
@PulumiTagMarker
public class XssMatchSetXssMatchTupleFieldToMatchArgsBuilder internal constructor() {
    private var `data`: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value When `type` is `HEADER`, enter the name of the header that you want to search, e.g., `User-Agent` or `Referer`.
     * If `type` is any other value, omit this field.
     */
    @JvmName("jhwwltckwppebucl")
    public suspend fun `data`(`value`: Output<String>) {
        this.`data` = value
    }

    /**
     * @param value The part of the web request that you want AWS WAF to search for a specified string.
     * e.g., `HEADER`, `METHOD` or `BODY`.
     * See [docs](http://docs.aws.amazon.com/waf/latest/APIReference/API_FieldToMatch.html)
     * for all supported values.
     */
    @JvmName("oqrmvnkemrarymqh")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value When `type` is `HEADER`, enter the name of the header that you want to search, e.g., `User-Agent` or `Referer`.
     * If `type` is any other value, omit this field.
     */
    @JvmName("qmubgjwyblakdvoh")
    public suspend fun `data`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`data` = mapped
    }

    /**
     * @param value The part of the web request that you want AWS WAF to search for a specified string.
     * e.g., `HEADER`, `METHOD` or `BODY`.
     * See [docs](http://docs.aws.amazon.com/waf/latest/APIReference/API_FieldToMatch.html)
     * for all supported values.
     */
    @JvmName("pbqfrjxhbtwslsvl")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): XssMatchSetXssMatchTupleFieldToMatchArgs =
        XssMatchSetXssMatchTupleFieldToMatchArgs(
            `data` = `data`,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/waf/kotlin/inputs/XssMatchSetXssMatchTupleFieldToMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.waf.kotlin.inputs

import com.pulumi.aws.waf.inputs.XssMatchSetXssMatchTupleFieldToMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property data When `type` is `HEADER`, enter the name of the header that you want to search, e.g., `User-Agent` or `Referer`.
 * If `type` is any other value, omit this field.
 * @property type The part of the web request that you want AWS WAF to search for a specified string.
 * e.g., `HEADER`, `METHOD` or `BODY`.
 * See [docs](http://docs.aws.amazon.com/waf/latest/APIReference/API_FieldToMatch.html)
 * for all supported values.
 */
public data class XssMatchSetXssMatchTupleFieldToMatchArgs(
    public val `data`: Output<String>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.waf.inputs.XssMatchSetXssMatchTupleFieldToMatchArgs> {
    override fun toJava(): com.pulumi.aws.waf.inputs.XssMatchSetXssMatchTupleFieldToMatchArgs =
        com.pulumi.aws.waf.inputs.XssMatchSetXssMatchTupleFieldToMatchArgs.builder()
            .`data`(`data`?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [XssMatchSetXssMatchTupleFieldToMatchArgs].
 */
@PulumiTagMarker
public class XssMatchSetXssMatchTupleFieldToMatchArgsBuilder internal constructor() {
    private var `data`: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value When `type` is `HEADER`, enter the name of the header that you want to search, e.g., `User-Agent` or `Referer`.
     * If `type` is any other value, omit this field.
     */
    @JvmName("pcrvxrxmhmmoohlq")
    public suspend fun `data`(`value`: Output<String>) {
        this.`data` = value
    }

    /**
     * @param value The part of the web request that you want AWS WAF to search for a specified string.
     * e.g., `HEADER`, `METHOD` or `BODY`.
     * See [docs](http://docs.aws.amazon.com/waf/latest/APIReference/API_FieldToMatch.html)
     * for all supported values.
     */
    @JvmName("dyahwjrvjokesjlp")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value When `type` is `HEADER`, enter the name of the header that you want to search, e.g., `User-Agent` or `Referer`.
     * If `type` is any other value, omit this field.
     */
    @JvmName("rqryrwockamrltap")
    public suspend fun `data`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`data` = mapped
    }

    /**
     * @param value The part of the web request that you want AWS WAF to search for a specified string.
     * e.g., `HEADER`, `METHOD` or `BODY`.
     * See [docs](http://docs.aws.amazon.com/waf/latest/APIReference/API_FieldToMatch.html)
     * for all supported values.
     */
    @JvmName("pephtwuvwtreqtrw")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): XssMatchSetXssMatchTupleFieldToMatchArgs =
        XssMatchSetXssMatchTupleFieldToMatchArgs(
            `data` = `data`,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}
